#include <usplash-theme.h>
#include <usplash-smooth.h>
#include <usplash_backend.h>



extern struct usplash_pixmap pixmap_usplash;
extern struct usplash_pixmap pixmap_throbber_back;
extern struct usplash_pixmap pixmap_throbber_fore;

int throbber_percentage = 0;



/****************************************************************************/



void theme_init( struct usplash_theme *theme )
{
    int x;
    int y;

    usplash_getdimensions( &x, &y );
    theme->progressbar_x = ( x - theme->pixmap->width  ) / 2 + theme->progressbar_x;
    theme->progressbar_y = ( y - theme->pixmap->height ) / 2 + theme->progressbar_y;

    usplash_smooth( theme );
}



void theme_clear_progressbar( struct usplash_theme *theme )
{
    usplash_put( theme->progressbar_x, theme->progressbar_y, &pixmap_throbber_back );
}



void theme_draw_progressbar( struct usplash_theme *theme, int percentage )
{
    throbber_percentage = percentage;
}



void theme_animate_step( struct usplash_theme* theme, int pulsating )
{
    int width;


    if( throbber_percentage == 0 ) {
        theme_clear_progressbar( theme );
        return;
    }


    width = pixmap_throbber_back.width * time_percentage( );

    if( throbber_percentage > 0 ) {
        usplash_put_part( theme->progressbar_x, theme->progressbar_y, width, pixmap_throbber_back.height, &pixmap_throbber_fore, 0, 0 );
        usplash_put_part( theme->progressbar_x + width, theme->progressbar_y, pixmap_throbber_back.width - width, pixmap_throbber_back.height, &pixmap_throbber_back, width, 0 );
    }

    if( throbber_percentage < 0 ) {
        usplash_put_part( theme->progressbar_x, theme->progressbar_y, width, pixmap_throbber_back.height, &pixmap_throbber_back, 0, 0 );
        usplash_put_part( theme->progressbar_x + width, theme->progressbar_y, pixmap_throbber_back.width - width, pixmap_throbber_back.height, &pixmap_throbber_fore, width, 0 );
    }
}



/****************************************************************************/



struct usplash_theme usplash_theme = {
  .version = THEME_VERSION,
  .next = NULL,
  .ratio = USPLASH_4_3,

  /* Background and font */
  .pixmap = &pixmap_usplash,

  /* Palette indexes */
  .background             = 0,
  .progressbar_background = 32,
  .progressbar_foreground = 131,
  .text_background        = 0,
  .text_foreground        = 117,
  .text_success           = 189,
  .text_failure           = 55,

  /* Progress bar position and size in pixels */
  .progressbar_x          = 352,
  .progressbar_y          = 400,
  .progressbar_width      = 320,
  .progressbar_height     = 18,

  /* Text box position and size in pixels */
  .text_x                 = 322,
  .text_y                 = 475,
  .text_width             = 380,
  .text_height            = 200,

  /* Text details */
  .line_height            = 15,
  .line_length            = 32,
  .status_width           = 35,

  /* Functions */
  .init = theme_init,
  .clear_progressbar = theme_clear_progressbar,
  .draw_progressbar = theme_draw_progressbar,
  .animate_step = theme_animate_step,
};

